@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '1.0.23.0';
+our $VERSION = '1.2.2.0';
 
 use Exporter 'import';
 
@@ -12,6 +12,7 @@ use Search::Xapian::Database;
 use Search::Xapian::Document;
 use Search::Xapian::ESet;
 use Search::Xapian::ESetIterator;
+use Search::Xapian::Error;
 use Search::Xapian::MSet;
 use Search::Xapian::MSetIterator;
 use Search::Xapian::MultiValueSorter;
@@ -37,11 +38,6 @@ require DynaLoader;
 
 our @ISA = qw(DynaLoader);
 
-# We need to use the RTLD_GLOBAL flag to dlopen() so that other C++
-# modules that link against libxapian.so get the *same* value for all the
-# weak symbols (eg, the exception classes)
-sub dl_load_flags { 0x01 }
-
 # This allows declaration	use Search::Xapian ':all';
 # If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
 # will save memory.
